EXPORTS
	??0RMidiControllerCustomCommands@@QAE@AAVRMMFController@@@Z @ 1 NONAME ; public: __thiscall RMidiControllerCustomCommands::RMidiControllerCustomCommands(class RMMFController &)
	??0CMMFMidiEvent@@QAE@VTUid@@H@Z @ 2 NONAME ; public: __thiscall CMMFMidiEvent::CMMFMidiEvent(class TUid,int)
	??0CMMFMidiEvent@@QAE@XZ @ 3 NONAME ; public: __thiscall CMMFMidiEvent::CMMFMidiEvent(void)
	??1CMidiCustomCommandParser@@UAE@XZ @ 4 NONAME ; public: virtual __thiscall CMidiCustomCommandParser::~CMidiCustomCommandParser(void)
	??1CMMFMidiEvent@@UAE@XZ @ 5 NONAME ; public: virtual __thiscall CMMFMidiEvent::~CMMFMidiEvent(void)
	?CancelReceiveEvents@RMidiControllerCustomCommands@@QAEHXZ @ 6 NONAME ; public: int __thiscall RMidiControllerCustomCommands::CancelReceiveEvents(void)
	?ChannelVolume@RMidiControllerCustomCommands@@QBEHHAAM@Z @ 7 NONAME ; public: int __thiscall RMidiControllerCustomCommands::ChannelVolume(int,float &)const 
	?ChannelsSupported@RMidiControllerCustomCommands@@QBEHAAH@Z @ 8 NONAME ; public: int __thiscall RMidiControllerCustomCommands::ChannelsSupported(int &)const 
	?Close@RMidiControllerCustomCommands@@QAEHXZ @ 9 NONAME ; public: int __thiscall RMidiControllerCustomCommands::Close(void)
	?CopyL@CMMFMidiEvent@@QAEXABV1@@Z @ 10 NONAME ; public: void __thiscall CMMFMidiEvent::CopyL(class CMMFMidiEvent const &)
	?CustomBankLoaded@RMidiControllerCustomCommands@@QBEHHAAH@Z @ 11 NONAME ; public: int __thiscall RMidiControllerCustomCommands::CustomBankLoaded(int,int &)const 
	?DurationMicroBeats@RMidiControllerCustomCommands@@QBEHAA_J@Z @ 12 NONAME ; public: int __thiscall RMidiControllerCustomCommands::DurationMicroBeats(long long &)const 
	?ExternalizeL@CMMFMidiEvent@@QBEXAAVRWriteStream@@@Z @ 13 NONAME ; public: void __thiscall CMMFMidiEvent::ExternalizeL(class RWriteStream &)const 
	?GetBalance@RMidiControllerCustomCommands@@QBEHAAH@Z @ 14 NONAME ; public: int __thiscall RMidiControllerCustomCommands::GetBalance(int &)const 
	?GetBankId@RMidiControllerCustomCommands@@QBEHHHAAH@Z @ 15 NONAME ; public: int __thiscall RMidiControllerCustomCommands::GetBankId(int,int,int &)const 
	?GetInstrument@RMidiControllerCustomCommands@@QAEHHAAH0@Z @ 16 NONAME ; public: int __thiscall RMidiControllerCustomCommands::GetInstrument(int,int &,int &)
	?GetInstrumentId@RMidiControllerCustomCommands@@QBEHHHHAAH@Z @ 17 NONAME ; public: int __thiscall RMidiControllerCustomCommands::GetInstrumentId(int,int,int,int &)const 
	?GetRepeats@RMidiControllerCustomCommands@@QBEHAAH@Z @ 18 NONAME ; public: int __thiscall RMidiControllerCustomCommands::GetRepeats(int &)const 
	?InstrumentNameL@RMidiControllerCustomCommands@@QBEPAVHBufC16@@HHH@Z @ 19 NONAME ; public: class HBufC16 * __thiscall RMidiControllerCustomCommands::InstrumentNameL(int,int,int)const 
	?InternalizeL@CMMFMidiEvent@@QAEXAAVRReadStream@@@Z @ 20 NONAME ; public: void __thiscall CMMFMidiEvent::InternalizeL(class RReadStream &)
	?IsChannelMute@RMidiControllerCustomCommands@@QBEHHAAH@Z @ 21 NONAME ; public: int __thiscall RMidiControllerCustomCommands::IsChannelMute(int,int &)const 
	?IsTrackMute@RMidiControllerCustomCommands@@QBEHHAAH@Z @ 22 NONAME ; public: int __thiscall RMidiControllerCustomCommands::IsTrackMute(int,int &)const 
	?LoadCustomBank@RMidiControllerCustomCommands@@QAEHABVTDesC16@@AAH@Z @ 23 NONAME ; public: int __thiscall RMidiControllerCustomCommands::LoadCustomBank(class TDesC16 const &,int &)
	?LoadCustomBankData@RMidiControllerCustomCommands@@QAEHABVTDesC8@@AAH@Z @ 24 NONAME ; public: int __thiscall RMidiControllerCustomCommands::LoadCustomBankData(class TDesC8 const &,int &)
	?LoadCustomInstrument@RMidiControllerCustomCommands@@QAEHABVTDesC16@@HHHH@Z @ 25 NONAME ; public: int __thiscall RMidiControllerCustomCommands::LoadCustomInstrument(class TDesC16 const &,int,int,int,int)
	?LoadCustomInstrumentData@RMidiControllerCustomCommands@@QAEHABVTDesC8@@HHHH@Z @ 26 NONAME ; public: int __thiscall RMidiControllerCustomCommands::LoadCustomInstrumentData(class TDesC8 const &,int,int,int,int)
	?MaxChannelVolume@RMidiControllerCustomCommands@@QBEHAAM@Z @ 27 NONAME ; public: int __thiscall RMidiControllerCustomCommands::MaxChannelVolume(float &)const 
	?MaxPlaybackRate@RMidiControllerCustomCommands@@QBEHAAH@Z @ 28 NONAME ; public: int __thiscall RMidiControllerCustomCommands::MaxPlaybackRate(int &)const 
	?MaxVolume@RMidiControllerCustomCommands@@QBEHAAH@Z @ 29 NONAME ; public: int __thiscall RMidiControllerCustomCommands::MaxVolume(int &)const 
	?MimeType@RMidiControllerCustomCommands@@QBEHAAVTDes8@@@Z @ 30 NONAME ; public: int __thiscall RMidiControllerCustomCommands::MimeType(class TDes8 &)const 
	?MinPlaybackRate@RMidiControllerCustomCommands@@QBEHAAH@Z @ 31 NONAME ; public: int __thiscall RMidiControllerCustomCommands::MinPlaybackRate(int &)const 
	?NewL@CMidiCustomCommandParser@@SAPAV1@AAVMMidiCustomCommandImplementor@@@Z @ 32 NONAME ; public: static class CMidiCustomCommandParser * __cdecl CMidiCustomCommandParser::NewL(class MMidiCustomCommandImplementor &)
	?NoteOff@RMidiControllerCustomCommands@@QAEHHHH@Z @ 33 NONAME ; public: int __thiscall RMidiControllerCustomCommands::NoteOff(int,int,int)
	?NoteOn@RMidiControllerCustomCommands@@QAEHHHH@Z @ 34 NONAME ; public: int __thiscall RMidiControllerCustomCommands::NoteOn(int,int,int)
	?NumTracks@RMidiControllerCustomCommands@@QBEHAAH@Z @ 35 NONAME ; public: int __thiscall RMidiControllerCustomCommands::NumTracks(int &)const 
	?NumberOfBanks@RMidiControllerCustomCommands@@QBEHHAAH@Z @ 36 NONAME ; public: int __thiscall RMidiControllerCustomCommands::NumberOfBanks(int,int &)const 
	?NumberOfInstruments@RMidiControllerCustomCommands@@QBEHHHAAH@Z @ 37 NONAME ; public: int __thiscall RMidiControllerCustomCommands::NumberOfInstruments(int,int,int &)const 
	?PercussionKeyNameL@RMidiControllerCustomCommands@@QBEPAVHBufC16@@HHHH@Z @ 38 NONAME ; public: class HBufC16 * __thiscall RMidiControllerCustomCommands::PercussionKeyNameL(int,int,int,int)const 
	?PitchTranspositionCents@RMidiControllerCustomCommands@@QBEHAAH@Z @ 39 NONAME ; public: int __thiscall RMidiControllerCustomCommands::PitchTranspositionCents(int &)const 
	?PlayNote@RMidiControllerCustomCommands@@QAEHHHABVTTimeIntervalMicroSeconds@@0HH@Z @ 40 NONAME ; public: int __thiscall RMidiControllerCustomCommands::PlayNote(int,int,class TTimeIntervalMicroSeconds const &,class TTimeIntervalMicroSeconds const &,int,int)
	?PlayNote@RMidiControllerCustomCommands@@QAEHHHABVTTimeIntervalMicroSeconds@@HH@Z @ 41 NONAME ; public: int __thiscall RMidiControllerCustomCommands::PlayNote(int,int,class TTimeIntervalMicroSeconds const &,int,int)
	?PlaybackRate@RMidiControllerCustomCommands@@QBEHAAH@Z @ 42 NONAME ; public: int __thiscall RMidiControllerCustomCommands::PlaybackRate(int &)const 
	?Polyphony@RMidiControllerCustomCommands@@QBEHAAH@Z @ 43 NONAME ; public: int __thiscall RMidiControllerCustomCommands::Polyphony(int &)const 
	?PositionMicroBeats@RMidiControllerCustomCommands@@QBEHAA_J@Z @ 44 NONAME ; public: int __thiscall RMidiControllerCustomCommands::PositionMicroBeats(long long &)const 
	?ReceiveEvents@RMidiControllerCustomCommands@@QAEXAAV?$TPckgBuf@H@@AAVTRequestStatus@@@Z @ 45 NONAME ; public: void __thiscall RMidiControllerCustomCommands::ReceiveEvents(class TPckgBuf<int> &,class TRequestStatus &)
	?RetrieveEvent@RMidiControllerCustomCommands@@QAEHAAVTDes8@@@Z @ 46 NONAME ; public: int __thiscall RMidiControllerCustomCommands::RetrieveEvent(class TDes8 &)
	?SendMessage@RMidiControllerCustomCommands@@QAEHABVTDesC8@@AAH@Z @ 47 NONAME ; public: int __thiscall RMidiControllerCustomCommands::SendMessage(class TDesC8 const &,int &)
	?SendMessage@RMidiControllerCustomCommands@@QAEHABVTDesC8@@ABVTTimeIntervalMicroSeconds@@AAH@Z @ 48 NONAME ; public: int __thiscall RMidiControllerCustomCommands::SendMessage(class TDesC8 const &,class TTimeIntervalMicroSeconds const &,int &)
	?SendMipMessage@RMidiControllerCustomCommands@@QAEHABV?$RArray@VTMipMessageEntry@@@@@Z @ 49 NONAME ; public: int __thiscall RMidiControllerCustomCommands::SendMipMessage(class RArray<class TMipMessageEntry> const &)
	?SetBalance@RMidiControllerCustomCommands@@QAEHH@Z @ 50 NONAME ; public: int __thiscall RMidiControllerCustomCommands::SetBalance(int)
	?SetBank@RMidiControllerCustomCommands@@QAEHH@Z @ 51 NONAME ; public: int __thiscall RMidiControllerCustomCommands::SetBank(int)
	?SetChannelMute@RMidiControllerCustomCommands@@QAEHHH@Z @ 52 NONAME ; public: int __thiscall RMidiControllerCustomCommands::SetChannelMute(int,int)
	?SetChannelVolume@RMidiControllerCustomCommands@@QAEHHM@Z @ 53 NONAME ; public: int __thiscall RMidiControllerCustomCommands::SetChannelVolume(int,float)
	?SetInstrument@RMidiControllerCustomCommands@@QAEHHHH@Z @ 54 NONAME ; public: int __thiscall RMidiControllerCustomCommands::SetInstrument(int,int,int)
	?SetMaxPolyphony@RMidiControllerCustomCommands@@QAEHH@Z @ 55 NONAME ; public: int __thiscall RMidiControllerCustomCommands::SetMaxPolyphony(int)
	?SetPitchTransposition@RMidiControllerCustomCommands@@QAEHHAAH@Z @ 56 NONAME ; public: int __thiscall RMidiControllerCustomCommands::SetPitchTransposition(int,int &)
	?SetPlaybackRate@RMidiControllerCustomCommands@@QAEHH@Z @ 57 NONAME ; public: int __thiscall RMidiControllerCustomCommands::SetPlaybackRate(int)
	?SetPositionMicroBeats@RMidiControllerCustomCommands@@QBEH_J@Z @ 58 NONAME ; public: int __thiscall RMidiControllerCustomCommands::SetPositionMicroBeats(long long)const 
	?SetStopTime@RMidiControllerCustomCommands@@QBEHABVTTimeIntervalMicroSeconds@@@Z @ 59 NONAME ; public: int __thiscall RMidiControllerCustomCommands::SetStopTime(class TTimeIntervalMicroSeconds const &)const 
	?SetSyncUpdateCallbackInterval@RMidiControllerCustomCommands@@QAEHABVTTimeIntervalMicroSeconds@@_J@Z @ 60 NONAME ; public: int __thiscall RMidiControllerCustomCommands::SetSyncUpdateCallbackInterval(class TTimeIntervalMicroSeconds const &,long long)
	?SetTempo@RMidiControllerCustomCommands@@QAEHH@Z @ 61 NONAME ; public: int __thiscall RMidiControllerCustomCommands::SetTempo(int)
	?SetTrackMute@RMidiControllerCustomCommands@@QBEHHH@Z @ 62 NONAME ; public: int __thiscall RMidiControllerCustomCommands::SetTrackMute(int,int)const 
	?SetVolume@RMidiControllerCustomCommands@@QAEHH@Z @ 63 NONAME ; public: int __thiscall RMidiControllerCustomCommands::SetVolume(int)
	?SetVolumeRamp@RMidiControllerCustomCommands@@QAEHABVTTimeIntervalMicroSeconds@@@Z @ 64 NONAME ; public: int __thiscall RMidiControllerCustomCommands::SetVolumeRamp(class TTimeIntervalMicroSeconds const &)
	?Stop@RMidiControllerCustomCommands@@QAEHABVTTimeIntervalMicroSeconds@@@Z @ 65 NONAME ; public: int __thiscall RMidiControllerCustomCommands::Stop(class TTimeIntervalMicroSeconds const &)
	?StopNotes@RMidiControllerCustomCommands@@QAEHH@Z @ 66 NONAME ; public: int __thiscall RMidiControllerCustomCommands::StopNotes(int)
	?StopTime@RMidiControllerCustomCommands@@QBEHAAVTTimeIntervalMicroSeconds@@@Z @ 67 NONAME ; public: int __thiscall RMidiControllerCustomCommands::StopTime(class TTimeIntervalMicroSeconds &)const 
	?TempoMicroBeatsPerMinute@RMidiControllerCustomCommands@@QBEHAAH@Z @ 68 NONAME ; public: int __thiscall RMidiControllerCustomCommands::TempoMicroBeatsPerMinute(int &)const 
	?UnloadAllCustomBanks@RMidiControllerCustomCommands@@QAEHXZ @ 69 NONAME ; public: int __thiscall RMidiControllerCustomCommands::UnloadAllCustomBanks(void)
	?UnloadCustomBank@RMidiControllerCustomCommands@@QAEHH@Z @ 70 NONAME ; public: int __thiscall RMidiControllerCustomCommands::UnloadCustomBank(int)
	?UnloadCustomInstrument@RMidiControllerCustomCommands@@QAEHHH@Z @ 71 NONAME ; public: int __thiscall RMidiControllerCustomCommands::UnloadCustomInstrument(int,int)
	?Volume@RMidiControllerCustomCommands@@QBEHAAH@Z @ 72 NONAME ; public: int __thiscall RMidiControllerCustomCommands::Volume(int &)const 
	?SetRepeats@RMidiControllerCustomCommands@@QAEHHABVTTimeIntervalMicroSeconds@@@Z @ 73 NONAME ; public: int __thiscall RMidiControllerCustomCommands::SetRepeats(int,class TTimeIntervalMicroSeconds const &)
	?MaxPolyphony@RMidiControllerCustomCommands@@QBEHAAH@Z @ 74 NONAME ; public: int __thiscall RMidiControllerCustomCommands::MaxPolyphony(int &)const 

